@@ -1,8 +1,10 @@
 package Reddit::Client;
 
-our $VERSION = '1.29';
+our $VERSION = '1.292'; # 2/4/19 not live yet
+# 1.292 -added crosspost_parent to Link
+# 1.291 -print_request_on_error was accidentally left on in get_links_by_id
 # TODO: make ispost, iscomment and get_type static
-# 1.29  -added is_original_content flag to Link
+# 1.29  -added is_original_content flag to Link 1/6/19
 # 1.2817-documentation update
 # 1.281 -morecomments get_collapsed args
 # 1.281 -get_collapsed can also return morecomments
@@ -688,8 +690,6 @@ sub get_links_by_id {
 	die "get_links_by_id: argument 1 (\@fullnames) is required.\n" unless @fullnames;
 	@fullnames = map { fullname($_, 't3') } @fullnames;
 	my $str = join ",", @fullnames;	
-	#my $result = $self->api_json_request(
-	$self->{print_request_on_error} = 1;
 	my $result = $self->json_request('GET', $API[API_BY_ID][1]."/$str");
 
 	return [
